==> jc-1.4.0.tar.gz: java/security/cert/CertPathBuilderException.h <==
// public class java.security.cert.CertPathBuilderException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class 511aa1db071b8c8f java_security_cert_CertPathBuilderException

// header file dependencies
// @dep_header java_security_GeneralSecurityException

#include "java/security/GeneralSecurityException.h"

#ifndef _JC_java_security_cert_CertPathBuilderException_H_
#define _JC_java_security_cert_CertPathBuilderException_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathBuilderException$sub_refs	_jc_java_security_cert_CertPathBuilderException$sub_refs;
typedef struct _jc_java_security_cert_CertPathBuilderException$sub_nonrefs	_jc_java_security_cert_CertPathBuilderException$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderException$refs	_jc_java_security_cert_CertPathBuilderException$refs;
typedef struct _jc_java_security_cert_CertPathBuilderException$nonrefs	_jc_java_security_cert_CertPathBuilderException$nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderException$object	_jc_java_security_cert_CertPathBuilderException$object;

typedef struct _jc_java_security_cert_CertPathBuilderException$fields_struct	_jc_java_security_cert_CertPathBuilderException$fields_struct;
typedef const struct _jc_java_security_cert_CertPathBuilderException$vmethods	_jc_java_security_cert_CertPathBuilderException$vmethods;
typedef const struct _jc_java_security_cert_CertPathBuilderException$vtable	_jc_java_security_cert_CertPathBuilderException$vtable;
typedef const struct _jc_java_security_cert_CertPathBuilderException$vtype	_jc_java_security_cert_CertPathBuilderException$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPathBuilderException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertPathBuilderException$fields_struct _jc_java_security_cert_CertPathBuilderException$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_security_cert_CertPathBuilderException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilderException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
extern void _jc_java_security_cert_CertPathBuilderException$method$printStackTrace$0c533e6284fdc6db(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
extern void _jc_java_security_cert_CertPathBuilderException$method$printStackTrace$0235c4ad6dac60e9(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintStream$object *);
extern void _jc_java_security_cert_CertPathBuilderException$method$printStackTrace$a53e2b4b86a79644(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintWriter$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilderException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$printStackTrace$0c533e6284fdc6db;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$printStackTrace$0235c4ad6dac60e9;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$printStackTrace$a53e2b4b86a79644;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_CertPathBuilderException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
	void	(*printStackTrace$0c533e6284fdc6db)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
	void	(*printStackTrace$0235c4ad6dac60e9)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintStream$object *);
	void	(*printStackTrace$a53e2b4b86a79644)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintWriter$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *);
};

// Vtable
struct _jc_java_security_cert_CertPathBuilderException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_java_security_cert_CertPathBuilderException$vmethods	java_security_cert_CertPathBuilderException;
};

// Vtype
struct _jc_java_security_cert_CertPathBuilderException$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathBuilderException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderException$refs {
    _jc_java_security_cert_CertPathBuilderException$sub_refs	java_security_cert_CertPathBuilderException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_java_security_cert_CertPathBuilderException$sub_nonrefs	java_security_cert_CertPathBuilderException;
};

// Object instance structure
struct _jc_java_security_cert_CertPathBuilderException$object {
	_jc_java_security_cert_CertPathBuilderException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathBuilderException$vtype	*vtype;
	_jc_java_security_cert_CertPathBuilderException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathBuilderException$vtype _jc_java_security_cert_CertPathBuilderException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathBuilderException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathBuilderException$class_object;

#endif	/* _JC_java_security_cert_CertPathBuilderException_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertPathBuilderException.h <==
// public class java.security.cert.CertPathBuilderException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class 511aa1db071b8c8f java_security_cert_CertPathBuilderException

// header file dependencies
// @dep_header java_security_GeneralSecurityException

#include "java/security/GeneralSecurityException.h"

#ifndef _JC_java_security_cert_CertPathBuilderException_H_
#define _JC_java_security_cert_CertPathBuilderException_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathBuilderException$sub_refs	_jc_java_security_cert_CertPathBuilderException$sub_refs;
typedef struct _jc_java_security_cert_CertPathBuilderException$sub_nonrefs	_jc_java_security_cert_CertPathBuilderException$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderException$refs	_jc_java_security_cert_CertPathBuilderException$refs;
typedef struct _jc_java_security_cert_CertPathBuilderException$nonrefs	_jc_java_security_cert_CertPathBuilderException$nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderException$object	_jc_java_security_cert_CertPathBuilderException$object;

typedef struct _jc_java_security_cert_CertPathBuilderException$fields_struct	_jc_java_security_cert_CertPathBuilderException$fields_struct;
typedef const struct _jc_java_security_cert_CertPathBuilderException$vmethods	_jc_java_security_cert_CertPathBuilderException$vmethods;
typedef const struct _jc_java_security_cert_CertPathBuilderException$vtable	_jc_java_security_cert_CertPathBuilderException$vtable;
typedef const struct _jc_java_security_cert_CertPathBuilderException$vtype	_jc_java_security_cert_CertPathBuilderException$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPathBuilderException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertPathBuilderException$fields_struct _jc_java_security_cert_CertPathBuilderException$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertPathBuilderException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_security_cert_CertPathBuilderException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilderException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertPathBuilderException$method$printStackTrace$0c533e6284fdc6db(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertPathBuilderException$method$printStackTrace$0235c4ad6dac60e9(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertPathBuilderException$method$printStackTrace$a53e2b4b86a79644(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathBuilderException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$printStackTrace$0c533e6284fdc6db;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$printStackTrace$0235c4ad6dac60e9;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$printStackTrace$a53e2b4b86a79644;
extern _jc_method _jc_java_security_cert_CertPathBuilderException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_CertPathBuilderException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$0c533e6284fdc6db)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$0235c4ad6dac60e9)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
	void	(*printStackTrace$a53e2b4b86a79644)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertPathBuilderException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_java_security_cert_CertPathBuilderException$vmethods	java_security_cert_CertPathBuilderException;
};

// Vtype
struct _jc_java_security_cert_CertPathBuilderException$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathBuilderException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderException$refs {
    _jc_java_security_cert_CertPathBuilderException$sub_refs	java_security_cert_CertPathBuilderException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_java_security_cert_CertPathBuilderException$sub_nonrefs	java_security_cert_CertPathBuilderException;
};

// Object instance structure
struct _jc_java_security_cert_CertPathBuilderException$object {
	_jc_java_security_cert_CertPathBuilderException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathBuilderException$vtype	*vtype;
	_jc_java_security_cert_CertPathBuilderException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathBuilderException$vtype _jc_java_security_cert_CertPathBuilderException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathBuilderException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathBuilderException$class_object;

#endif	/* _JC_java_security_cert_CertPathBuilderException_H_ */
